@@ -30,17 +30,17 @@
  *
  * \author  Niels Lohmann <nlohmann@informatik.hu-berlin.de>,
  *          Christian Gierds <gierds@informatik.hu-berlin.de>,
- *          last changes of: \$Author: nielslohmann $
+ *          last changes of: \$Author: gierds $
  *
  * \since   2006/02/08
  *
- * \date    \$Date: 2007/06/28 07:38:15 $
+ * \date    \$Date: 2007/08/10 11:09:04 $
  *
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.72 $
+ * \version \$Revision: 1.75 $
  *
  * \ingroup debug
  * \ingroup creation
@@ -67,7 +67,7 @@
 #include "petrinet.h"
 
 using std::pair;
-
+using namespace PNapi;
 
 
 
@@ -195,7 +195,7 @@ void footer(kc::integer id, bool myindent)
  */
 void process_loop_bounds(const vector<unsigned int> &loop_bounds, const vector<unsigned int> &loop_identifiers, string prefix, unsigned int my_max)
 {
-  extern PetriNet PN;	// introduced in main.c
+  extern PNapi::PetriNet PN;	// introduced in main.c
 
   vector<unsigned int> current_index(loop_bounds.size(), 1);
   unsigned int number = 1;
@@ -263,6 +263,8 @@ void process_loop_bounds(const vector<unsigned int> &loop_bounds, const vector<u
 
 namespace {
     map< pair< unsigned int, unsigned int >, activityRelationType > activityRelationMap;
+    map< unsigned int, set< unsigned int > > beforeActivities;
+    map< unsigned int, set< unsigned int > > afterActivities;
 }
 
 
@@ -373,8 +375,43 @@ void enterEnclosedActivities( unsigned int a, set< unsigned int > b )
 void consecutiveActivities( unsigned int a, unsigned int b )
 {
     ENTER("consecutiveActivities");
-    activityRelationMap[pair<unsigned int, unsigned int>(a,b)] = AR_BEFORE;
-    activityRelationMap[pair<unsigned int, unsigned int>(b,a)] = AR_AFTER;
+    beforeActivities[b].insert(a);
+    afterActivities[a].insert(b);
+    for (set< unsigned int >::iterator first = beforeActivities[b].begin(); first != beforeActivities[b].end(); first++)
+    {
+        for (set< unsigned int >::iterator second = afterActivities[a].begin(); second != afterActivities[a].end(); second++)
+        {
+            activityRelationMap[pair<unsigned int, unsigned int>(*first,*second)] = AR_BEFORE;
+            activityRelationMap[pair<unsigned int, unsigned int>(*second,*first)] = AR_AFTER;
+            beforeActivities[*second].insert(*first);
+            afterActivities[*first].insert(*second);
+            for (set< unsigned int >::iterator innerFirst = globals::ASTEmap[ *first ]->enclosedActivities.begin(); innerFirst != globals::ASTEmap[ *first ]->enclosedActivities.end(); innerFirst++)
+            {
+                for (set< unsigned int >::iterator innerSecond = globals::ASTEmap[ *second ]->enclosedActivities.begin(); innerSecond != globals::ASTEmap[ *second ]->enclosedActivities.end(); innerSecond++)
+                {
+                    activityRelationMap[pair<unsigned int, unsigned int>(*innerFirst,*innerSecond)] = AR_BEFORE;
+                    activityRelationMap[pair<unsigned int, unsigned int>(*innerSecond,*innerFirst)] = AR_AFTER;
+                    beforeActivities[*innerSecond].insert(*innerFirst);
+                    afterActivities[*innerFirst].insert(*innerSecond);
+                }            
+            }
+            for (set< unsigned int >::iterator innerFirst = globals::ASTEmap[ *first ]->enclosedActivities.begin(); innerFirst != globals::ASTEmap[ *first ]->enclosedActivities.end(); innerFirst++)
+            {
+                    activityRelationMap[pair<unsigned int, unsigned int>(*innerFirst,*second)] = AR_BEFORE;
+                    activityRelationMap[pair<unsigned int, unsigned int>(*second,*innerFirst)] = AR_AFTER;
+                    beforeActivities[*second].insert(*innerFirst);
+                    afterActivities[*innerFirst].insert(*second);
+            }
+                for (set< unsigned int >::iterator innerSecond = globals::ASTEmap[ *second ]->enclosedActivities.begin(); innerSecond != globals::ASTEmap[ *second ]->enclosedActivities.end(); innerSecond++)
+                {
+                    activityRelationMap[pair<unsigned int, unsigned int>(*first,*innerSecond)] = AR_BEFORE;
+                    activityRelationMap[pair<unsigned int, unsigned int>(*innerSecond,*first)] = AR_AFTER;
+                    beforeActivities[*innerSecond].insert(*first);
+                    afterActivities[*first].insert(*innerSecond);
+                }            
+        } 
+    }
+    
     LEAVE("consecutiveActivities");
 }
 
