@@ -35,13 +35,13 @@
  *
  * \since   2005/10/18
  *
- * \date    \$Date: 2007/06/28 07:38:15 $
+ * \date    \$Date: 2007/08/07 12:01:37 $
  *
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.185 $
+ * \version \$Revision: 1.194 $
  */
 
 
@@ -75,7 +75,7 @@ using std::cout;
 using std::endl;
 using std::string;
 using std::map;
-
+using namespace PNapi;
 
 
 
@@ -94,6 +94,16 @@ extern int frontend__flex_debug;		// from flex
 extern FILE *frontend_in;			// from flex
 extern void frontend_restart(FILE*);		// from flex
 
+extern int frontend_owfn_debug;			// from Bison
+extern int frontend_owfn_flex_debug;
+
+extern FILE *frontend_owfn_in;
+extern int frontend_owfn_error();
+extern int frontend_owfn_parse();
+
+extern int frontend_pnml_debug;			// from Bison
+
+extern int frontend_pnml_parse();
 
 
 
@@ -209,7 +219,7 @@ void single_output(set< string >::iterator file)
       globals::AST->fprintdot(dotfile, "", "", "", true, true, true);
       fclose(dotfile);
 #ifdef HAVE_DOT
-      string systemcall = "dot -q -Tpng -o" + globals::output_filename + ".png " + globals::output_filename + "." + suffixes[F_DOT];
+      string systemcall = "dot -q -Tpng -o\"" + globals::output_filename + ".png\" \"" + globals::output_filename + "." + suffixes[F_DOT] + "\"";
       trace(TRACE_INFORMATION, "Invoking dot with the following options:\n");
       trace(TRACE_INFORMATION, systemcall + "\n\n");
       system(systemcall.c_str());
@@ -237,7 +247,7 @@ void single_output(set< string >::iterator file)
         output = NULL;
       }
       #ifdef HAVE_DOT
-      string systemcall = "dot -q -Tpng -o" + globals::output_filename + ".png " + globals::output_filename + "." + suffixes[F_DOT];
+      string systemcall = "dot -q -Tpng -o\"" + globals::output_filename + ".png\" \"" + globals::output_filename + "." + suffixes[F_DOT] + "\"";
       trace(TRACE_INFORMATION, "Invoking dot with the following options:\n");
       trace(TRACE_INFORMATION, systemcall + "\n\n");
       system(systemcall.c_str());
@@ -406,7 +416,15 @@ void final_output()
     {
       if (globals::output_filename != "")
       {
-        output = openOutput(globals::output_filename + "." + suffixes[F_OWFN]);
+        if (options[O_NET] && globals::net_mode == OWFN)
+        {
+          output = openOutput(globals::output_filename + "Gen." + suffixes[F_OWFN]);
+          trace(TRACE_ALWAYS, "Output filename for owfn2owfn is [OLDNAME]Gen.owfn \n");
+        }
+        else
+        {
+          output = openOutput(globals::output_filename + "." + suffixes[F_OWFN]);
+        }
       }
       trace(TRACE_INFORMATION, "-> Printing Petri net for oWFN ...\n");
       PN.set_format(FORMAT_OWFN);
@@ -417,8 +435,8 @@ void final_output()
         output = NULL;
       }
     }
-
-
+    
+    
     // create LoLA output ?
     if ( formats[F_LOLA] )
     {
@@ -467,14 +485,22 @@ void final_output()
         }
       }
     }
-
-
+    
+    
     // create PNML output ?
     if ( formats[F_PNML] )
     {
       if (globals::output_filename != "")
       {
-        output = openOutput(globals::output_filename + "." + suffixes[F_PNML]);
+        if (options[O_NET] && globals::net_mode == PNML)
+        {
+          output = openOutput(globals::output_filename + "Gen." + suffixes[F_PNML]);
+          trace(TRACE_ALWAYS, "Output filename for pnml2pnml is [OLDNAME]Gen.pnml \n");
+        }
+        else
+        {
+          output = openOutput(globals::output_filename + "." + suffixes[F_PNML]);
+        }
       }
       trace(TRACE_INFORMATION, "-> Printing Petri net for PNML ...\n");
       PN.set_format(FORMAT_PNML);
@@ -485,8 +511,26 @@ void final_output()
         output = NULL;
       }
     }
+    
 
-
+    // create I/O-annotated LoLA output ?
+    if ( formats[F_IOLOLA] )
+    {
+      if (globals::output_filename != "")
+      {
+        output = openOutput(globals::output_filename + "." + suffixes[F_IOLOLA]);
+      }
+      trace(TRACE_INFORMATION, "-> Printing Petri net for I/O-annotated LoLA ...\n");
+      PN.set_format(FORMAT_IOLOLA);
+      (*output) << PN;
+      if (globals::output_filename != "")
+      {
+        closeOutput(output);
+        output = NULL;
+      }
+    }
+    
+    
     // create PEP output ?
     if ( formats[F_PEP] )
     {
@@ -503,8 +547,8 @@ void final_output()
         output = NULL;
       }
     }
-
-
+    
+    
     // create INA output ?
     if ( formats[F_INA] )
     {
@@ -538,7 +582,7 @@ void final_output()
         output = NULL;
       }
     }
-
+    
     // create APNN output ?
     if ( formats[F_APNN] )
     {
@@ -573,17 +617,17 @@ void final_output()
       {
         closeOutput(output);
         output = NULL;
-
+        
 #ifdef HAVE_DOT
-	string systemcall = "dot -q -Tpng -o" + globals::output_filename + ".png " + globals::output_filename + "." + suffixes[F_DOT];
+        string systemcall = "dot -q -Tpng -o\"" + globals::output_filename + ".png\" \"" + globals::output_filename + "." + suffixes[F_DOT] + "\"";
 	trace(TRACE_INFORMATION, "Invoking dot with the following options:\n");
 	trace(TRACE_INFORMATION, systemcall + "\n\n");
 	system(systemcall.c_str());
 #endif
       }
     }
-
-
+    
+    
     // create info file ?
     if ( formats[F_INFO] )
     {
@@ -628,9 +672,11 @@ void final_output()
  */
 int main( int argc, char *argv[])
 {
+
   // initilization of variables
   PetriNet PN2 = PetriNet();
 
+
   // analyzation of the commandline
   analyze_cl(argc,argv);
 
@@ -667,10 +713,10 @@ int main( int argc, char *argv[])
 
     show_process_information_header();
 
-    // invoke Bison BPEL4Chor parser
-    trace(TRACE_INFORMATION, "Parsing " + globals::choreography_filename + " ...\n");
+    // invoke Bison BPEL4WSDL parser
+    trace(TRACE_INFORMATION, "Parsing " + globals::wsdl_filename + " ...\n");
     int parse_result = frontend_wsdl_parse();
-    trace(TRACE_INFORMATION, "Parsing of " + globals::choreography_filename + " complete.\n");
+    trace(TRACE_INFORMATION, "Parsing of " + globals::wsdl_filename + " complete.\n");
 
     close_file(globals::wsdl_filename);
 
@@ -679,61 +725,115 @@ int main( int argc, char *argv[])
 
     show_wsdl_information();
   }
-  
 
-
-  // parsing all inputfiles
-  set< string >::iterator file = inputfiles.begin();
-  do
+  /*
+   * parse an OWFN file
+   */
+  if (globals::net_filename != "")
   {
-    if (file != inputfiles.end())
-    {
-      open_file(*file);
 
-      // reset the parser
-      frontend_restart(frontend_in);      
-    }
-
-    show_process_information_header();
-
-
-    // invoke BPEL Bison parser
-    trace(TRACE_INFORMATION, "Parsing " + globals::filename + " ...\n");
-    frontend_parse();
-    trace(TRACE_INFORMATION, "Parsing of " + globals::filename + " complete.\n");
+    globals::filename = globals::net_filename;
     
-    globals::parsing = false;
-    
-    if (file != inputfiles.end())
-      close_file(*file);
-    
-    if (frontend_nerrs == 0)
+    if (globals::net_mode == OWFN)
     {
-      finish_AST();
-      single_output(file);
-    }
-    else /* parse error */
-    {
-      if (globals::AST == NULL)
+      if (!(frontend_owfn_in = fopen(globals::filename.c_str(), "r"))) 
       {
-        genericError(104, "", toString(frontend_lineno), ERRORLEVEL_CRITICAL);
-        
-        cleanup();
-        return 3;
+        cerr << "Could not open file for reading: " << globals::filename.c_str() << endl;
+        exit(2);
       }
-      else
+  
+      show_process_information_header();
+  
+      // invoke Bison BPEL4WSDL parser
+      trace(TRACE_INFORMATION, "Parsing " + globals::net_filename + " ...\n");
+      int parse_result = frontend_owfn_parse();
+      trace(TRACE_INFORMATION, "Parsing of " + globals::net_filename + " complete.\n");
+  
+      // closing a file
+      trace(TRACE_INFORMATION," + Closing owfn file: " + globals::filename + "\n");
+      fclose(frontend_owfn_in);
+      frontend_owfn_in = NULL;
+    }
+    else if (globals::net_mode == PNML)
+    {
+      if (!(frontend_in = fopen(globals::filename.c_str(), "r"))) 
+      {
+        cerr << "Could not open file for reading: " << globals::filename.c_str() << endl;
+        exit(2);
+      }
+  
+      show_process_information_header();
+  
+      // invoke Bison BPEL4WSDL parser
+      trace(TRACE_INFORMATION, "Parsing " + globals::net_filename + " ...\n");
+      int parse_result = frontend_pnml_parse();
+      trace(TRACE_INFORMATION, "Parsing of " + globals::net_filename + " complete.\n");
+  
+      // closing a file
+      trace(TRACE_INFORMATION," + Closing pnml file: " + globals::filename + "\n");
+      fclose(frontend_in);
+      frontend_in = NULL;
+    }
+    else
+    {
+      trace(TRACE_INFORMATION, "No parsable files.");
+      globals::output_filename = "";
+    }
+  }
+  else
+  {
+    // parsing all inputfiles
+    set< string >::iterator file = inputfiles.begin();
+    do
+    {
+      if (file != inputfiles.end())
+      {
+        open_file(*file);
+  
+        // reset the parser
+        frontend_restart(frontend_in);      
+      }
+  
+      show_process_information_header();
+  
+  
+      // invoke BPEL Bison parser
+      trace(TRACE_INFORMATION, "Parsing " + globals::filename + " ...\n");
+      frontend_parse();
+      trace(TRACE_INFORMATION, "Parsing of " + globals::filename + " complete.\n");
+      
+      globals::parsing = false;
+      
+      if (file != inputfiles.end())
+        close_file(*file);
+      
+      if (frontend_nerrs == 0)
       {
-        genericError(105, "", toString(frontend_lineno), ERRORLEVEL_NOTICE);
-        
         finish_AST();
         single_output(file);
       }
-    }
-
-    file++;
-
-  } while (modus == M_CHOREOGRAPHY && file != inputfiles.end());
-
+      else /* parse error */
+      {
+        if (globals::AST == NULL)
+        {
+          genericError(104, "", toString(frontend_lineno), ERRORLEVEL_CRITICAL);
+          
+          cleanup();
+          return 3;
+        }
+        else
+        {
+          genericError(105, "", toString(frontend_lineno), ERRORLEVEL_NOTICE);
+          
+          finish_AST();
+          single_output(file);
+        }
+      }
+  
+      file++;
+  
+    } while (modus == M_CHOREOGRAPHY && file != inputfiles.end());
+  }
   trace(TRACE_INFORMATION, "All files have been parsed.\n");
 
   final_output();
