@@ -30,17 +30,17 @@
  *
  * \author  Niels Lohmann <nlohmann@informatik.hu-berlin.de>,
  *          Christian Gierds <gierds@informatik.hu-berlin.de>,
- *          last changes of: \$Author: nielslohmann $
+ *          last changes of: \$Author: znamirow $
  *
  * \since   2005/11/09
  *          
- * \date    \$Date: 2007/06/28 07:38:15 $
+ * \date    \$Date: 2007/07/25 09:28:07 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.106 $
+ * \version \$Revision: 1.111 $
  *
  * \ingroup debug
  */
@@ -207,7 +207,7 @@ void show_process_information()
   if (globals::static_analysis_errors == 0)
   {
     cerr << colorconsole::fg_green << "[STATIC ANALYSIS] " << colorconsole::fg_standard;
-    cerr << "No errors found checking 51 statics analysis requirements." << endl;
+    cerr << "No errors found checking 56 statics analysis requirements." << endl;
   }
   else if (globals::abstract_process)
   {
@@ -274,6 +274,33 @@ void show_wsdl_information()
  *
  * \ingroup debug
  */
+int frontend_owfn_error(const char *msg)
+{ 
+  /* defined by flex */
+  extern int frontend_owfn_lineno;      // line number of current token
+  extern char *frontend_owfn_text;      // text of the current token
+
+  cerr << colorconsole::fg_blue;
+  cerr << globals::filename << ":" << frontend_owfn_lineno+1 << " - [SYNTAX]\n";
+  cerr << colorconsole::fg_standard;
+
+  if (debug_level == TRACE_ERROR)
+    return 1;
+
+  cerr << string(msg);
+
+  if (debug_level >= TRACE_WARNINGS)
+    cerr << "; last token read: `" << string(frontend_owfn_text) << "'" << endl << endl;
+  else
+    cerr << endl << endl;
+
+  // remember the last token
+  globals::last_error_token = string(frontend_owfn_text);
+  globals::last_error_line = toString(frontend_owfn_lineno);
+
+  return 1;
+}
+
 int frontend_error(const char *msg)
 {
   /* defined by flex */
@@ -689,7 +716,7 @@ void SAerror(unsigned int code, string information, int lineNumber)
 	break; }
 
     case(60):
-      { cerr << "ould not find an explicit corresponding incoming message activity for the <reply>" << endl;
+      { cerr << "could not find an explicit corresponding incoming message activity for the <reply>" << endl;
 	break; }
 
     case(61):
