@@ -161,10 +161,30 @@
      K_SCHEMA = 377,
      K_PROPERTY = 378,
      K_PROPERTYALIAS = 379,
-     NUMBER = 380,
-     X_NAME = 381,
-     VARIABLENAME = 382,
-     X_STRING = 383
+     P_NET = 380,
+     P_PLACE = 381,
+     P_GRAPHICS = 382,
+     P_NAME = 383,
+     P_DESCRIPTION = 384,
+     P_TRANSITION = 385,
+     P_PAGE = 386,
+     P_POSITION = 387,
+     P_TEXT = 388,
+     P_INITIALMARKING = 389,
+     P_DIMENSION = 390,
+     P_PNML = 391,
+     P_ARC = 392,
+     P_INSCRIPTION = 393,
+     P_OFFSET = 394,
+     P_REFERENCEPLACE = 395,
+     P_TYPE = 396,
+     P_TRANSFORMATION = 397,
+     P_TOOLSPECIFIC = 398,
+     NUMBER = 399,
+     X_NAME = 400,
+     VARIABLENAME = 401,
+     X_STRING = 402,
+     X_TEXT = 403
    };
 #endif
 /* Tokens.  */
@@ -290,10 +310,30 @@
 #define K_SCHEMA 377
 #define K_PROPERTY 378
 #define K_PROPERTYALIAS 379
-#define NUMBER 380
-#define X_NAME 381
-#define VARIABLENAME 382
-#define X_STRING 383
+#define P_NET 380
+#define P_PLACE 381
+#define P_GRAPHICS 382
+#define P_NAME 383
+#define P_DESCRIPTION 384
+#define P_TRANSITION 385
+#define P_PAGE 386
+#define P_POSITION 387
+#define P_TEXT 388
+#define P_INITIALMARKING 389
+#define P_DIMENSION 390
+#define P_PNML 391
+#define P_ARC 392
+#define P_INSCRIPTION 393
+#define P_OFFSET 394
+#define P_REFERENCEPLACE 395
+#define P_TYPE 396
+#define P_TRANSFORMATION 397
+#define P_TOOLSPECIFIC 398
+#define NUMBER 399
+#define X_NAME 400
+#define VARIABLENAME 401
+#define X_STRING 402
+#define X_TEXT 403
 
 
 
