@@ -29,17 +29,17 @@
  * \brief   global varialbes
  *
  * \author  Niels Lohmann <nlohmann@informatik.hu-berlin.de>,
- *          last changes of: \$Author: nielslohmann $
+ *          last changes of: \$Author: znamirow $
  * 
  * \since   2007/03/05
  *
- * \date    \$Date: 2007/06/28 07:38:16 $
+ * \date    \$Date: 2007/07/23 12:43:09 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.32 $
+ * \version \$Revision: 1.34 $
  */
 
 
@@ -59,6 +59,7 @@
 
 
 
+
 namespace globals {
   string currentScope;
 
@@ -131,6 +132,8 @@ namespace globals {
 
   string wsdl_filename = "";
 
+  string net_filename = "";
+
   WSDL WSDLInfo = WSDL();
 
   BPEL4Chor BPEL4ChorInfo = BPEL4Chor();
@@ -140,4 +143,10 @@ namespace globals {
   int instances_of_current_process = 0;
   
   map<unsigned int, unsigned int> if_branches;
+
+  map<string, string> owfn_commands;
+  
+  string owfn_statepredicate;
+  
+  net_modes net_mode;
 }
