@@ -33,13 +33,13 @@
  * 
  * \since   2007/03/05
  *
- * \date    \$Date: 2007/06/28 07:38:16 $
+ * \date    \$Date: 2007/07/30 19:56:41 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.34 $
+ * \version \$Revision: 1.37 $
  */
 
 
@@ -116,6 +116,16 @@ struct s_wsdl_information
 };
 
 
+/*!
+ * \brief net reading modes
+ */
+typedef enum
+{
+  OWFN,		  ///< OWFN file
+  PNML,			///< PNML file
+  NONE      ///< Not a valid format
+} net_modes;
+
 
 
 
@@ -142,6 +152,9 @@ namespace globals
 
   /// set of output channel names
   extern map<string, unsigned int> ASTE_outputChannels;
+  
+  /// a mapping from channel names to port names
+  extern map<string, string> ASTE_channel_to_port;
 
   /// set of (prefixed) correlation set names
   extern set<string> ASTE_correlationSetNames;
@@ -229,6 +242,9 @@ namespace globals
   /// filename of the optional WSDL file
   extern string wsdl_filename;  
 
+  /// filename of the OWFN file
+  extern string net_filename;  
+
   /// parameters (set by #parse_command_line)
   extern map<possibleParameters, bool> parameters;
 
@@ -273,6 +289,16 @@ namespace globals
   
   /// a mapping holding the number of branches for every <if> activity (indexed by the <if>'s id)
   extern map<unsigned int, unsigned int> if_branches;
+  
+  /// a mapping for the commands that are attached to nodes in owfn files
+  extern map<string,string> owfn_commands;
+
+  /// the statepredicate of an owfn file
+  extern string owfn_statepredicate;
+  
+  /// the mode of reading a petrinet file
+  extern net_modes net_mode;
+  
 }
 
 #endif
