@@ -34,13 +34,13 @@
  * 
  * \since   2005/11/11
  *
- * \date    \$Date: 2007/06/28 07:38:16 $
+ * \date    \$Date: 2007/07/18 08:17:48 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.83 $
+ * \version \$Revision: 1.84 $
  *
  * \ingroup debug
  */
@@ -53,9 +53,12 @@
  * Headers
  *****************************************************************************/
 
+#include <iostream>
 #include <fstream>	// (std::ofstream)
 #include <sstream>	// (std::ostringstream, std::istringstream)
 #include <cassert>
+#include <string>
+#include <vector>
 
 #include "debug.h"	// (trace)
 #include "helpers.h"
@@ -68,6 +71,8 @@ using std::cerr;
 using std::clog;
 using std::flush;
 using std::ofstream;
+using std::string;
+using std::vector;
 
 
 
