@@ -35,13 +35,13 @@
  *
  * \since   2005/10/18
  *
- * \date    \$Date: 2007/06/28 07:38:16 $
+ * \date    \$Date: 2007/08/07 12:01:37 $
  *
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.89 $
+ * \version \$Revision: 1.98 $
  */
 
 
@@ -126,11 +126,12 @@ static struct option longopts[] =
   { "reduce",		required_argument, NULL, 'r' },
   { "topology",		required_argument, NULL, 't' },
   { "wsdl",		required_argument, NULL, 'w' },
+  { "net",		required_argument, NULL, 'n' },
   NULL
 };
 
 /// short options (needed by GNU getopt)
-const char *par_string = "hvm:li:of:p:d:r:t:w:";
+const char *par_string = "hvm:li:of:p:d:r:t:w:n:";
 
 
 
@@ -164,6 +165,7 @@ void print_help()
   trace(" -v, --version          print program version and exit\n");
   trace(" -t, --topology=FILE    read a BPEL4Chor participant topology file from FILE\n");
   trace(" -w, --wsdl=FILE        read a WSDL file from FILE\n");
+  trace(" -n, --net=FILE         read an OWFN or PNML file from FILE\n");
   trace("\n");
   trace("  MODE is one of the following (at most one mode permitted):\n");
   trace("    petrinet            create a Petri net model\n");
@@ -225,6 +227,7 @@ void parse_command_line(int argc, char* argv[])
 {
   // suffixes stores the file suffixes for the various supported file types
   suffixes[F_LOLA] = "lola"  ;
+  suffixes[F_IOLOLA] = "iolola"  ;
   suffixes[F_OWFN] = "owfn"  ;
   suffixes[F_DOT]  = "dot"   ;
   suffixes[F_INA]  = "pnt";
@@ -237,7 +240,7 @@ void parse_command_line(int argc, char* argv[])
   suffixes[F_XML]  = "xml"   ;
   
   // this array helps us to automatically check the valid formats
-  possibleFormats format[] = { F_LOLA, F_OWFN, F_DOT, F_INA, F_SPIN, F_PEP, F_APNN, F_INFO, F_PNML, F_TXT, F_XML };
+  possibleFormats format[] = { F_LOLA, F_OWFN, F_DOT, F_INA, F_SPIN, F_PEP, F_APNN, F_INFO, F_PNML, F_TXT, F_XML, F_IOLOLA };
   
   // this map indicates, whether a certain format is valid for a mode
   map< pair<possibleModi,possibleFormats>, bool > validFormats;
@@ -255,7 +258,8 @@ void parse_command_line(int argc, char* argv[])
   validFormats[pair<possibleModi,possibleFormats>(M_PETRINET,F_APNN)] = true;
   validFormats[pair<possibleModi,possibleFormats>(M_PETRINET,F_INFO)] = true;
   validFormats[pair<possibleModi,possibleFormats>(M_PETRINET,F_PNML)] = true;
-  
+
+  validFormats[pair<possibleModi,possibleFormats>(M_CHOREOGRAPHY,F_IOLOLA)] = true;  
   validFormats[pair<possibleModi,possibleFormats>(M_CHOREOGRAPHY,F_LOLA)] = true;
   validFormats[pair<possibleModi,possibleFormats>(M_CHOREOGRAPHY,F_OWFN)] = true;
   validFormats[pair<possibleModi,possibleFormats>(M_CHOREOGRAPHY,F_DOT )] = true;
@@ -277,6 +281,9 @@ void parse_command_line(int argc, char* argv[])
   // turn off debug modi of flex and bison by default
   frontend_debug = 0;
   frontend__flex_debug = 0;
+  frontend_owfn_debug = 0;
+  frontend_owfn__flex_debug = 0;
+  frontend_pnml_debug = 0;
   
   
   // use GNU getopt to parse the command-line arguments
@@ -393,6 +400,8 @@ void parse_command_line(int argc, char* argv[])
           formats[F_INFO] = true;
         else if (parameter == "ina")
           formats[F_INA] = true;
+        else if (parameter == "iolola")
+          formats[F_IOLOLA] = true;
         else if (parameter == "spin")
           formats[F_SPIN] = true;
         else if (parameter == suffixes[F_PNML])
@@ -438,6 +447,8 @@ void parse_command_line(int argc, char* argv[])
           globals::parameters[P_DEADLOCKTEST] = true;
         else if (parameter == "data")
           globals::parameters[P_DATA] = true;
+        else if (parameter == "ports")
+          globals::parameters[P_PORTS] = true;
         else {
           trace(TRACE_ALWAYS, "Unknown parameter \"" + parameter +"\".\n");
           trace(TRACE_ALWAYS, "Use -h to get a list of valid parameters.\n");
@@ -454,9 +465,16 @@ void parse_command_line(int argc, char* argv[])
         parameter = string(optarg);
         
         if (parameter == "flex")
+        {
           frontend__flex_debug = 1;
+          frontend_owfn__flex_debug = 1;
+        }
         else if (parameter == "bison")
+        {
           frontend_debug = 1;
+          frontend_owfn_debug = 1;
+          frontend_pnml_debug = 1;
+        }
         else if (parameter == "1")
           debug_level = TRACE_WARNINGS;
         else if (parameter == "2")
@@ -503,6 +521,33 @@ void parse_command_line(int argc, char* argv[])
         globals::wsdl_filename = string(optarg);
         break;
       }
+
+      case 'n':
+      {
+        options[O_NET] = true;
+        
+        // set the mode to Petri net
+        modus = M_PETRINET;
+        string suffix;
+        suffix = string(optarg).substr(string(optarg).length()-4);
+        if (suffix == "owfn")
+        {
+          globals::net_filename = string(optarg);
+          globals::net_mode = OWFN;
+        }
+        else if (suffix == "pnml")
+        {
+          globals::net_filename = string(optarg);
+          globals::net_mode = PNML;
+        }
+        else
+        {
+        globals::net_mode = NONE;
+        trace(string(optarg) + " does not have a valid filetype!\n");
+        trace(TRACE_ALWAYS, "Use -h to get a list of valid filetypes.\n");
+        }
+        break;
+      }
         
       default:
       {
@@ -592,8 +637,16 @@ void parse_command_line(int argc, char* argv[])
     // set output file name to a standard output filename in case of no inputfiles
     if ( not(options[O_INPUT]) )
     {
-      globals::output_filename = "stdof"; 
-      trace(TRACE_ALWAYS, "Output filename set to standard: stdof\n");
+      if (options[O_NET])
+      {
+        unsigned int pos = globals::net_filename.length() - 5;
+        globals::output_filename = globals::net_filename.substr(0, pos);
+      }
+      else
+      {
+        globals::output_filename = "stdof"; 
+        trace(TRACE_ALWAYS, "Output filename set to standard: stdof\n");
+      }
     } 
     else 
     {
@@ -603,6 +656,10 @@ void parse_command_line(int argc, char* argv[])
       {
         globals::output_filename = file->substr(0, pos);
       }
+      else
+      {
+        globals::output_filename = *file;
+      }
       file++;
       while(modus == M_CHOREOGRAPHY && file != inputfiles.end())
       {
