@@ -34,13 +34,13 @@
  *
  * \since   2005/10/18
  *
- * \date    \$Date: 2007/06/28 07:38:16 $
+ * \date    \$Date: 2007/08/07 12:01:37 $
  *
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.58 $
+ * \version \$Revision: 1.64 $
  */
 
 
@@ -95,7 +95,8 @@ typedef enum
    O_DEBUG,		///< set the debug level
    O_REDUCTION,		///< set level of structural reduction
    O_TOPOLOGY,		///< parse a choreography file (BPEL4Chor)
-   O_WSDL		///< parse a WSDL file
+   O_WSDL,		///< parse a WSDL file
+   O_NET		///< parse an oWFN or PNML file
 } possibleOptions;
 
 
@@ -134,7 +135,8 @@ typedef enum
   F_INFO,		///< BPEL2oWFN information file
   F_PNML,		///< Petri Net Markup Language
   F_TXT,		///< ASCII output (for the abstract syntax tree)
-  F_XML			///< XML output (for pretty-printed BPEL)
+  F_XML,		///< XML output (for pretty-printed BPEL)
+  F_IOLOLA		///< LoLA Petri net with I/O annotation
 } possibleFormats;
 
 
@@ -155,7 +157,8 @@ typedef enum
   P_LOOPCONTROL,	///< add communication to loops
   P_NOINTERFACE,	///< do not draw an interface
   P_DEADLOCKTEST,	///< removes the deadlock from the final place
-  P_DATA		///< creates multiple nets (Diplomarbeit Thomas Heidinger)   
+  P_DATA,		///< creates multiple nets (Diplomarbeit Thomas Heidinger)
+  P_PORTS		///< outputs ports (affects oWFN and dot output)
 } possibleParameters;
 
 
@@ -196,6 +199,9 @@ extern map<possibleFormats,  string> suffixes;
 
 extern int frontend_debug;
 extern int frontend__flex_debug;
+extern int frontend_owfn_debug;
+extern int frontend_owfn__flex_debug;
+extern int frontend_pnml_debug;
 extern FILE *frontend_in;
 
 
