@@ -34,13 +34,13 @@
  *
  * \since   created: 2006-03-16
  *
- * \date    \$Date: 2007/06/28 07:38:17 $
+ * \date    \$Date: 2007/07/27 14:24:19 $
  *
  * \note    This file is part of the tool GNU BPEL2oWFN and was created during
  *          the project Tools4BPEL at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.101 $
+ * \version \$Revision: 1.106 $
  *
  * \ingroup petrinet
  */
@@ -67,7 +67,7 @@ using std::setw;
 using std::right;
 using std::left;
 
-
+using namespace PNapi;
 
 
 
@@ -80,7 +80,7 @@ using std::left;
  *
  *          dummy-implementation of virtual function
  */
-string Node::nodeTypeName() const
+string PNapi::Node::nodeTypeName() const
 {
   return "";
 }
@@ -122,7 +122,7 @@ string Transition::nodeTypeName() const
  *
  *          dummy-implementation of virtual function
  */
-string Node::nodeShortName() const
+string PNapi::Node::nodeShortName() const
 {
   return "";
 }
@@ -136,7 +136,7 @@ string Node::nodeShortName() const
  *
  * \return  the (nice) name of the node for DOT output
  */
-string Node::nodeName() const
+string PNapi::Node::nodeName() const
 {
   string result = *history.begin();
 
@@ -158,7 +158,7 @@ string Node::nodeName() const
  *
  * \return  the name of the node for DOT output
  */
-string Node::nodeFullName() const
+string PNapi::Node::nodeFullName() const
 {
   string result = *history.begin();
 
@@ -1157,12 +1157,19 @@ void PetriNet::output_owfn(ostream *output) const
   
   (*output) << "{" << endl;
   (*output) << "  generated by: " << PACKAGE_STRING << endl;
+  if (options[O_NET])
+  {
+    (*output) << "  input file:   `" << globals::filename << "')" << endl;  
+  }
+  else
+  {
 #ifdef USING_BPEL2OWFN
   (*output) << "  input file:   `" << globals::filename << "' (process `" << globals::ASTEmap[1]->attributes["name"] << "')" << endl;
 #endif
 #ifndef USING_BPEL2OWFN
   (*output) << "  input file:   `" << globals::filename << "'" << endl;
 #endif
+  }
   (*output) << "  invocation:   `" << globals::invocation << "'" << endl;
   (*output) << "  net size:     " << information() << endl;
   (*output) << "}" << endl << endl;
@@ -1199,10 +1206,17 @@ void PetriNet::output_owfn(ostream *output) const
     (*output) << "    " << (*p)->nodeName();
 #endif
     
-    if ((*p)->max_occurrences != UINT_MAX && (*p)->max_occurrences != 0)
-      (*output) << " {$ MAX_OCCURRENCES = " << (*p)->max_occurrences << " $}";
-    if ((*p)->max_occurrences == UINT_MAX)
-      (*output) << " {$ MAX_OCCURRENCES = -1 $}";
+    if (options[O_NET])
+    {
+      (*output) << " {$ " << globals::owfn_commands[(*p)->nodeName()] << " $}";
+    }
+    else
+    {
+      if ((*p)->max_occurrences != UINT_MAX && (*p)->max_occurrences != 0)
+        (*output) << " {$ MAX_OCCURRENCES = " << (*p)->max_occurrences << " $}";
+      if ((*p)->max_occurrences == UINT_MAX)
+        (*output) << " {$ MAX_OCCURRENCES = -1 $}";
+    }
     
     if (count < P_in.size())
       (*output) << "," << endl;
@@ -1221,19 +1235,54 @@ void PetriNet::output_owfn(ostream *output) const
     (*output) << "    " << (*p)->nodeName();
 #endif
     
-    if ((*p)->max_occurrences != UINT_MAX && (*p)->max_occurrences != 0)
-      (*output) << " {$ MAX_OCCURRENCES = " << (*p)->max_occurrences << " $}";
-    if ((*p)->max_occurrences == UINT_MAX)
-      (*output) << " {$ MAX_OCCURRENCES = -1 $}";
+    if (options[O_NET])
+    {
+      (*output) << " {$ " << globals::owfn_commands[(*p)->nodeName()] << " $}";
+    }
+    else
+    {
+      if ((*p)->max_occurrences != UINT_MAX && (*p)->max_occurrences != 0)
+        (*output) << " {$ MAX_OCCURRENCES = " << (*p)->max_occurrences << " $}";
+      if ((*p)->max_occurrences == UINT_MAX)
+        (*output) << " {$ MAX_OCCURRENCES = -1 $}";
+    }
     
     if (count < P_out.size())
       (*output) << "," << endl;
   }
-  (*output) << ";" << endl << endl << endl;
+  (*output) << ";" << endl << endl;
+  
+  
+  
+  // ports
+  if (!ports.empty())
+  {
+    (*output) << endl << "PORTS" << endl;
+    
+    for (map<string, set<Place*> >::const_iterator port = ports.begin();
+         port != ports.end(); port++)
+    {
+      (*output) << "  PORT " << port->first << ":" << endl;
+      
+      for (set<Place *>::const_iterator place = port->second.begin();
+           place != port->second.end(); place++)
+      {
+        if (place != port->second.begin())
+          (*output) << "," << endl;
+        
+        (*output) << "    " << (*place)->nodeShortName();
+      }
+      
+      (*output) << ";" << endl;
+    }
+    
+    (*output) << endl;
+  }
+  
   
   
   // initial marking
-  (*output) << "INITIALMARKING" << endl;
+  (*output) << endl << "INITIALMARKING" << endl;
   count = 1;
   for (set<Place *>::iterator p = P.begin(); p != P.end(); p++)
   {
@@ -1256,27 +1305,35 @@ void PetriNet::output_owfn(ostream *output) const
   
   
   // final marking
-  (*output) << "FINALMARKING" << endl;
-  count = 1;
-  for (set<Place *>::iterator p = P.begin(); p != P.end(); p++)
+  
+  if (globals::owfn_statepredicate == "")
   {
-    if ( (*p)->isFinal )
+    (*output) << "FINALCONDITION" << endl;
+    count = 1;
+    for (set<Place *>::iterator p = P.begin(); p != P.end(); p++)
     {
-      if (count != 1)
-        (*output) << ",";
-      
-#ifdef USING_BPEL2OWFN
-      (*output) << "  " << (*p)->nodeShortName();
-#else
-      (*output) << "  " << (*p)->nodeName();
-#endif
-      
-      (*output) << " {final place}";
-      
-      if (count++ != 1)
-        (*output) << endl;      
+      if ( (*p)->isFinal )
+      {
+        if (count != 1)
+          (*output) << " AND";
+        
+  #ifdef USING_BPEL2OWFN
+        (*output) << "  (" << (*p)->nodeShortName() << " = 1)";
+  #else
+        (*output) << "  (" << (*p)->nodeName() << " = 1)";
+  #endif
+        
+        // (*output) << " {final place}";
+        
+        if (count++ != 1)
+          (*output) << endl;      
+      }
     }
   }
+  else
+  {
+    (*output) << "FINALCONDITION" << endl << globals::owfn_statepredicate << endl; 
+  }
   (*output) << ";" << endl << endl << endl;
   
   
@@ -1349,7 +1406,7 @@ void PetriNet::output_owfn(ostream *output) const
  * \param   os  an output stream to which the net is streamed
  * \param   obj a PetriNet object
  */
-ostream& operator<< (ostream& os, const PetriNet &obj)
+ostream& PNapi::operator<< (ostream& os, const PNapi::PetriNet &obj)
 {
   switch (obj.format)
   {
